--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.Rendering.OpenGL.Raw.ARB.PointSprite
-- Copyright   :  (c) Sven Panne 2015
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
-- The <https://www.opengl.org/registry/specs/ARB/point_sprite.txt ARB_point_sprite> extension.
--
--------------------------------------------------------------------------------

module Graphics.Rendering.OpenGL.Raw.ARB.PointSprite (
  -- * Enums
  gl_COORD_REPLACE_ARB,
  gl_POINT_SPRITE_ARB
) where

import Graphics.Rendering.OpenGL.Raw.Tokens
